
###Script written to perform multiple ring buffers for individual polygons and appending the input attributes to the output for ArcMap 10.8 in Python 2.7.x by Alisha D.###

import arcpy, os

arcpy.env.overwriteOutput = True

#Set parameters for the script tool.
workspace = arcpy.GetParameterAsText(0)
inputfc= arcpy.GetParameterAsText(1)
outputfc= arcpy.GetParameterAsText(2)
bufferdist= arcpy.GetParameterAsText(3)

#Temporary feature classes which will be deleted later.
tempoutputfc= os.path.join(workspace,"tempoutputfc1")
tempoutputfc2= os.path.join(workspace,"tempoutputfc2")
tempoutputfc3= os.path.join(workspace,"tempoutputfc3")

# Replace a layer/table view name with a path to a dataset (which can be a layer file) or create the layer/table view within the script
# The following inputs are layers or table views: "Wetland_subset_Gust_Farms_Billys"
arcpy.MultipleRingBuffer_analysis(inputfc, tempoutputfc, bufferdist, "Meters", "distance", "NONE", "OUTSIDE_ONLY")
spatial_reference = arcpy.Describe(inputfc).spatialReference
arcpy.CreateFeatureclass_management(os.path.split(outputfc)[0],os.path.split(outputfc)[1],"POLYGON", tempoutputfc,"","",spatial_reference)

#Access individual feature using search cursor to prevent overlapping buffer dissolve and append it to a feature class
x=0
with arcpy.da.SearchCursor(inputfc, ['SHAPE@']) as cursor:
    for row in cursor:
        x +=1
        arcpy.AddMessage("Buffering and appending data for Polygon: " + str(x) +" ...")
        arcpy.MultipleRingBuffer_analysis(row, tempoutputfc2, bufferdist, "Meters", "distance", "ALL","OUTSIDE_ONLY")
        #Create the field mapping object and append the fields needed in the output, in this case, all.
        fms = arcpy.FieldMappings()
        fms.addTable(tempoutputfc2)
        fms.addTable(tempoutputfc)
        # Run the Spatial join tool.
        arcpy.SpatialJoin_analysis(tempoutputfc2, tempoutputfc, tempoutputfc3, "JOIN_ONE_TO_ONE", "KEEP_ALL", fms, "WITHIN")
        #Create the field mapping object for appending the data.
        fm= arcpy.FieldMappings()
        fm.addTable(tempoutputfc3)
        fm.addTable(outputfc)
        arcpy.Append_management(tempoutputfc3, outputfc, "NO_TEST", fm)


# arcpy.AddMessage("Spatially joing data.")

arcpy.AddMessage("Deleting temporary feature classes.")

#Delete the unrequired feature classes
arcpy.Delete_management(tempoutputfc)
arcpy.Delete_management(tempoutputfc2)
arcpy.Delete_management(tempoutputfc3)
