
###Script written to perform multiple ring buffers for individual polygons and appending the input attributes to the output for ArcMap 10.8 in Python 2.7.x by Alisha D.###

import arcpy, os, unicodedata

arcpy.env.overwriteOutput = True

#Set parameters for the script tool.
workspace = arcpy.GetParameterAsText(0)
inputfc= arcpy.GetParameterAsText(1)
outputfc= arcpy.GetParameterAsText(2)
bufferdist= arcpy.GetParameterAsText(3)

#Temporary feature classes which will be deleted later.
tempoutputfc= os.path.join(workspace,"tempoutputfc1")
tempoutputfc2= os.path.join(workspace,"tempoutputfc2")
tempoutputfc3= os.path.join(workspace,"tempoutputfc3")

arcpy.MultipleRingBuffer_analysis(inputfc, tempoutputfc, "50", "Meters", "distance", "NONE", "OUTSIDE_ONLY")
fields=['SHAPE@']

field_names = [f.name for f in arcpy.ListFields(tempoutputfc)]

for x in field_names:
    if x !='distance':
        y=unicodedata.normalize('NFKD', x).encode('ascii', 'ignore')
        fields.append(y)

spatial_reference = arcpy.Describe(inputfc).spatialReference
arcpy.CreateFeatureclass_management(os.path.split(outputfc)[0],os.path.split(outputfc)[1],"POLYGON", tempoutputfc,"","",spatial_reference)

#Access individual feature using search cursor to prevent overlapping buffer dissolve and append it to a feature class
x=0
with arcpy.da.SearchCursor(inputfc, ['SHAPE@']) as cursor:
    for row in cursor:
        x +=1
        arcpy.AddMessage("Buffering and appending data for Polygon: " + str(x) +" ...")
        arcpy.MultipleRingBuffer_analysis(row, tempoutputfc2, bufferdist, "Meters", "distance", "ALL","OUTSIDE_ONLY")
        fm= arcpy.FieldMappings()
        fm.addTable(outputfc)
        fm.addTable(tempoutputfc2)
        arcpy.Append_management(tempoutputfc2, outputfc, "NO_TEST",fm)


with arcpy.da.UpdateCursor(outputfc,fields) as cursor1:
    for row1 in cursor1:
        with arcpy.da.SearchCursor(tempoutputfc, fields) as cursor:
            for row in cursor:
                if row1[0].within(row[0]):
                    # for i in range(1,len(fields)+1):
                    #     row1[i]=row[i]
                    row1[1]=row[1]
                    row1[2]=row[2]
                    row1[3]=row[3]
                    row1[4]=row[4]
                    row1[5]=row[5]
                    row1[6]=row[6]
                    row1[7]=row[7]
                    row1[8]=row[8]
                    row1[9]=row[9]
                    row1[10]=row[10]
                    row1[11]=row[11]
                    row1[12]=row[12]
                    row1[13]=row[13]
                    row1[14]=row[14]
                    row1[15]=row[15]
                    row1[16]=row[16]
                    row1[17]=row[17]
                    row1[18]=row[18]
                    row1[19]=row[19]
                    row1[20]=row[20]
                    row1[21]=row[21]
                    cursor1.updateRow(row1)